@@ -1,7 +1,7 @@
 package Unix::Passwd::File;
 
-our $DATE = '2015-09-06'; # DATE
-our $VERSION = '0.21'; # VERSION
+our $DATE = '2015-10-22'; # DATE
+our $VERSION = '0.22'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,7 @@ use warnings;
 use experimental 'smartmatch';
 use Log::Any::IfLOG '$log';
 
-use File::Flock;
+use File::Flock::Retry;
 use List::Util qw(max first);
 use List::MoreUtils qw(firstidx);
 
@@ -295,22 +295,13 @@ sub _routine {
     my $etc     = $args{etc_dir} // "/etc";
     my $detail  = $args{detail};
     my $wfn     = $args{with_field_names} // 1;
-    my $locked;
+    my $lock;
     my ($fhp, $fhs, $fhg, $fhgs);
     my %stash;
 
     my $e = eval {
 
-        if ($args{_lock}) {
-            my $l;
-            for (1..3) {
-                $l = lock("$etc/passwd.lock", undef, 'nonblocking');
-                last if $l;
-                sleep 1;
-            }
-            return [412, "Can't lock $etc/passwd.lock"] unless $l;
-            $locked++;
-        }
+        $lock = File::Flock::Retry->lock("$etc/passwd.lock", {retries=>3});
 
         # read files
 
@@ -495,9 +486,7 @@ sub _routine {
     }; # eval
     $e = [500, "Died: $@"] if $@;
 
-    if ($locked) {
-        unlock("$etc/passwd.lock");
-    }
+    undef $lock;
 
     $stash{res} //= $e if $e && $e->[0] != 200;
     $stash{res} //= $e if $e && $e->[0] != 200;
@@ -1945,7 +1934,7 @@ Unix::Passwd::File - Manipulate /etc/{passwd,shadow,group,gshadow} entries
 
 =head1 VERSION
 
-This document describes version 0.21 of Unix::Passwd::File (from Perl distribution Unix-Passwd-File), released on 2015-09-06.
+This document describes version 0.22 of Unix::Passwd::File (from Perl distribution Unix-Passwd-File), released on 2015-10-22.
 
 =head1 SYNOPSIS
 
@@ -2036,6 +2025,8 @@ is equivalent to:
 
 except that C<add_delete_user_groups()> does it in one pass.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2072,6 +2063,8 @@ Return value:  (any)
 
 Add a new group.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2131,6 +2124,8 @@ Return value:  (any)
 
 Add a new user.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2253,6 +2248,8 @@ Return value:  (any)
 
 Add user to a group.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2283,6 +2280,8 @@ Return value:  (any)
 
 Delete a group.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2318,6 +2317,8 @@ Return value:  (any)
 
 Delete a user.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2353,6 +2354,8 @@ Return value:  (any)
 
 Delete user from a group.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2387,6 +2390,8 @@ Either C<group> OR C<gid> must be specified.
 
 The function is not dissimilar to Unix's C<getgrnam()> or C<getgrgid()>.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2425,6 +2430,8 @@ Return value:  (any)
 
 Get maximum GID used.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2451,6 +2458,8 @@ Return value:  (any)
 
 Get maximum UID used.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2481,6 +2490,8 @@ Either C<user> OR C<uid> must be specified.
 
 The function is not dissimilar to Unix's C<getpwnam()> or C<getpwuid()>.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2519,6 +2530,8 @@ Return value:  (any)
 
 Return groups which the user belongs to.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2560,6 +2573,8 @@ Return value:  (any)
 
 Check whether group exists.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2581,6 +2596,8 @@ Return value:  (bool)
 
 Check whether user is member of a group.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2602,6 +2619,8 @@ Return value:  (bool)
 
 List Unix groups in group file.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2641,6 +2660,8 @@ Return value:  (any)
 
 List Unix users in passwd file.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2684,6 +2705,8 @@ This is basically C<list_users()> and C<list_groups()> combined, so you can get
 both data in a single call. Data is returned in an array. Users list is in the
 first element, groups list in the second.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2721,6 +2744,8 @@ Modify an existing group.
 Specify arguments to modify corresponding fields. Unspecified fields will not be
 modified.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2781,6 +2806,8 @@ Modify an existing user.
 Specify arguments to modify corresponding fields. Unspecified fields will not be
 modified.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2866,6 +2893,8 @@ Return value:  (any)
 
 Set the groups that a user is member of.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2900,6 +2929,8 @@ Return value:  (any)
 
 Set user's password.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -2937,6 +2968,8 @@ Return value:  (any)
 
 Check whether user exists.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -3002,7 +3035,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Unix-Passw
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Unix-Passwd-File>.
+Source repository is at L<https://github.com/perlancar/perl-Unix-Passwd-File>.
 
 =head1 BUGS
 
